/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart;

/**
 * Represents a point on a cartesian plane with integer coordinate.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class IntPoint {
    /**
     * The x coordinate.
     */
    public int x = 0;

    /**
     * The y coordinate.
     */
    public int y = 0;

    /**
     * Constructs the point (0,0).
     */
    public IntPoint() {
        super();
    }

    /**
     * Copy constructor.
     * 
     * @param p
     *            the point to be copied
     */
    public IntPoint(IntPoint p) {
        super();
        this.x = p.x;
        this.y = p.y;
    }

    /**
     * Standard constructor.
     * 
     * @param x
     *            the point's x coordinate
     * @param y
     *            the point's y coordinate
     */
    public IntPoint(int x, int y) {
        super();
        this.x = x;
        this.y = y;
    }

    /**
     * Returns x.
     * 
     * @return x value
     */
    public double getX() {
        return this.x;
    }

    /**
     * Returns y.
     * 
     * @return y value
     */
    public double getY() {
        return this.y;
    }

    /**
     * Returns true if this point and the passed one coincide.
     * 
     * @param obj
     *            the point to test
     * @return true if the two objects are identical
     */
    /*public boolean equals(Object obj) {
        boolean result;
        if (!(obj instanceof IntPoint)) {
            result = false;
        } else {
            IntPoint p = (IntPoint) obj;
            result = this.x == p.getX() && this.y == p.getY();
        }
        return result;
    }*/

    /**
     * Returns a representaive string.
     * 
     * @return a string in the (x,y) format
     */
    public String toString() {
        return "(" + this.x + "," + this.y + ")";
    }

    /**
     * Sets the x value.
     * 
     * @param x
     *            the new x coordinate
     */
    public void setX(int x) {
        this.x = x;
    }

    /**
     * Sets the y value.
     * 
     * @param y
     *            the new y coordinate
     */
    public void setY(int y) {
        this.y = y;
    }
}