/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import org.nfunk.jep.ParseException;

/**
 * A convenient way to implement successions, that is, defining them with a
 * string that will be parsed.
 * 
 * @see ParsedFunction
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class ParsedSuccession extends AbstractDrawableSuccession {

    /**
     * Function used to calculate the values of this Succession
     */
    FunctionI internalFunction = null;

    /**
     * Default constructor ({an=n})
     */
    public ParsedSuccession() {
        super();
        try {
            this.internalFunction = new ParsedFunction("x");
        } catch (ParseException cantHappen) {
            // Never get here
        }
    }

    /**
     * Standard constructor, takes a string and makes up a Succession.
     * 
     * @see ParsedFunction
     * @see org.nfunk.jep.JEP
     * @param s
     *            the string to be parsed
     * @throws ParseException
     *             if the string isn't parsed correctly
     */
    public ParsedSuccession(String s) throws ParseException {
        super();
        this.internalFunction = new ParsedFunction(s);
    }

    /**
     * Returns the y value corresponding to the specified index n.
     * 
     * @param n
     *            the non-negative integer index
     * @return the value of the succession
     */
    public double f(int n) {
        if (n < 0) {
            throw new ArithmeticException();
        }
        return this.internalFunction.f(n);
    }

}